<?php

namespace pareviewsh\Composer;

use Composer\EventDispatcher\EventSubscriberInterface;
use Composer\Plugin\PluginInterface;
use Composer\Script\ScriptEvents;

/**
 * PareviewshComposerInstallerPlugin class.
 */
class PareviewshComposerInstallerPlugin implements PluginInterface, EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      ScriptEvents::PRE_INSTALL_CMD => 'preInstall',
      ScriptEvents::PRE_UPDATE_CMD => 'preUpdate',
      ScriptEvents::POST_INSTALL_CMD => 'postInstall',
      ScriptEvents::POST_UPDATE_CMD => 'postUpdate',
    ];
  }

  /**
   * Pre-install event for deleting environment configuration.
   *
   * @param \Composer\Installer\InstallerEvent $event
   *   Installer event.
   */
  public function preInstall(InstallerEvent $event) {
    // PareviewshComposerActions::deleteEnvironmentCfg($event->getComposer(), $event->getIO());
  }

  /**
   * Pre-update event for deleting environment configuration.
   *
   * @param \Composer\Installer\InstallerEvent $event
   *   Installer event.
   */
  public function preUpdate(InstallerEvent $event) {
    // PareviewshComposerActions::deleteEnvironmentCfg($event->getComposer(), $event->getIO());
  }

  /**
   * Post install event for installing dependencies and saving config.
   *
   * @param \Composer\Installer\InstallerEvent $event
   *   Installer event.
   */
  public function postInstall(InstallerEvent $event) {
    /* @var $composer \Composer\Composer */
    $composer = $event->getComposer();
    /* @var $io \Composer\IO\IOInterface */
    $io = $event->getIO();

    PareviewshComposerActions::installDependencies($composer, $io);
    PareviewshComposerActions::createEnvironmentCfg($composer, $io);
  }

  /**
   * Post update event for installing dependencies and saving config.
   *
   * @param \Composer\Installer\InstallerEvent $event
   *   Installer event.
   */
  public function postUpdate(InstallerEvent $event) {
    /* @var $composer \Composer\Composer */
    $composer = $event->getComposer();
    /* @var $io \Composer\IO\IOInterface */
    $io = $event->getIO();

    PareviewshComposerActions::installDependencies($composer, $io);
    PareviewshComposerActions::createEnvironmentCfg($composer, $io);
  }

}
